@@ -1,11 +1,14 @@
-
 from abc import ABC
-from typing import Callable, Optional, Union, Dict, Any, Tuple, Union, cast, List, Sequence, TypeVar
+from typing import Callable, Union
 
+import logging
+import numpy as np
 import torch
 from torch import Tensor
 
 from sbi.simulators.simutils import simulate_in_batches
+from sklearn.linear_model import LinearRegression
+from sklearn.preprocessing import PolynomialFeatures
 
 
 class ABCBASE(ABC):
@@ -60,6 +63,8 @@ class ABCBASE(ABC):
             show_progress_bars=self._show_progress_bars,
         )
 
+        self.logger = logging.getLogger(__name__)
+
     @staticmethod
     def choose_distance_function(distance_type: str = "l2") -> Callable:
         """Return distance function for given distance type."""
@@ -88,3 +93,65 @@ class ABCBASE(ABC):
             return distance(observed_data, simulated_data)
 
         return distance_fun
+
+    @staticmethod
+    def get_sass_transform(
+        theta: torch.Tensor,
+        x: torch.Tensor,
+        expansion_degree: int = 1,
+        sample_weight=None,
+    ) -> Callable:
+        """Return semi-automatic summary statitics function.
+
+        Running weighted linear regressin as in
+        Fearnhead & Prandle 2012: https://arxiv.org/abs/1004.1112
+
+        Following implementation in
+        https://abcpy.readthedocs.io/en/latest/_modules/abcpy/statistics.html#Identity
+        and
+        https://pythonhosted.org/abcpy/_modules/abcpy/summaryselections.html#Semiautomatic
+        """
+        expansion = PolynomialFeatures(degree=expansion_degree, include_bias=False)
+        # Transform x, remove intercept.
+        x_expanded = expansion.fit_transform(x)
+        sumstats_map = np.zeros((x_expanded.shape[1], theta.shape[1]))
+
+        for parameter_idx in range(theta.shape[1]):
+            regression_model = LinearRegression(fit_intercept=True)
+            regression_model.fit(
+                X=x_expanded, y=theta[:, parameter_idx], sample_weight=sample_weight
+            )
+            sumstats_map[:, parameter_idx] = regression_model.coef_
+
+        sumstats_map = torch.tensor(sumstats_map, dtype=torch.float32)
+
+        def sumstats_transform(x):
+            x_expanded = torch.tensor(expansion.fit_transform(x), dtype=torch.float32)
+            return x_expanded.mm(sumstats_map)
+
+        return sumstats_transform
+
+    @staticmethod
+    def run_lra(
+        theta: torch.Tensor,
+        x: torch.Tensor,
+        observation: torch.Tensor,
+        sample_weight=None,
+    ) -> torch.Tensor:
+        """Return parameters adjusted with linear regression adjustment.
+
+        Implementation as in Beaumont et al. 2002: https://arxiv.org/abs/1707.01254
+        """
+
+        theta_adjusted = theta
+        for parameter_idx in range(theta.shape[1]):
+            regression_model = LinearRegression(fit_intercept=True)
+            regression_model.fit(
+                X=x, y=theta[:, parameter_idx], sample_weight=sample_weight,
+            )
+            theta_adjusted[:, parameter_idx] += regression_model.predict(
+                observation.reshape(1, -1)
+            )
+            theta_adjusted[:, parameter_idx] -= regression_model.predict(x)
+
+        return theta_adjusted
