@@ -49,6 +49,7 @@ class NeuralPosterior(ABC):
         x_shape: torch.Size,
         mcmc_method: str = "slice_np",
         mcmc_parameters: Optional[Dict[str, Any]] = None,
+        device: str = "cpu",
     ):
         """
         Args:
@@ -68,6 +69,7 @@ class NeuralPosterior(ABC):
                 will draw init locations from prior, whereas `sir` will use Sequential-
                 Importance-Resampling. Init strategies may have their own keywords
                 which can also be set from `mcmc_parameters`.
+            device: Training device, e.g., cpu or cuda.
         """
         if method_family in ("snpe", "snle", "snre_a", "snre_b"):
             self._method_family = method_family
@@ -85,6 +87,7 @@ class NeuralPosterior(ABC):
         self._prior = prior
         self._x = None
         self._x_shape = x_shape
+        self._device = device
 
     @property
     def default_x(self) -> Optional[Tensor]:
@@ -302,6 +305,10 @@ class NeuralPosterior(ABC):
         mcmc_parameters = (
             mcmc_parameters if mcmc_parameters is not None else self.mcmc_parameters
         )
+
+        # Move x to current device.
+        x = x.to(self._device)
+
         return x, num_samples, mcmc_method, mcmc_parameters
 
     def _sample_posterior_mcmc(
