@@ -4,7 +4,7 @@
 
 from abc import ABC, abstractmethod
 from copy import deepcopy
-from typing import Any, Callable, Dict, NewType, Optional, Union, cast
+from typing import Any, Callable, Dict, Optional, Union
 from warnings import warn
 
 import torch
@@ -182,7 +182,7 @@ class PosteriorEstimator(NeuralInference, ABC):
 
         # Calibration kernels proposed in Lueckmann, Gonçalves et al., 2017.
         if calibration_kernel is None:
-            calibration_kernel = lambda x: ones([len(x)])
+            calibration_kernel = lambda x: ones([len(x)], device=self._device)
 
         max_num_epochs = 2 ** 31 - 1 if max_num_epochs is None else max_num_epochs
 
@@ -225,7 +225,7 @@ class PosteriorEstimator(NeuralInference, ABC):
         )
 
         # Dataset is shared for training and validation loaders.
-        dataset = data.TensorDataset(theta, x, prior_masks)
+        dataset = data.TensorDataset(theta, x, prior_masks,)
 
         # Create neural net and validation loaders using a subset sampler.
         train_loader = data.DataLoader(
@@ -242,6 +242,8 @@ class PosteriorEstimator(NeuralInference, ABC):
             sampler=SubsetRandomSampler(val_indices),
         )
 
+        # Move entire net to device for training.
+        self._neural_net.to(self._device)
         optimizer = optim.Adam(list(self._neural_net.parameters()), lr=learning_rate,)
 
         epoch, self._val_log_prob = 0, float("-Inf")
@@ -251,6 +253,7 @@ class PosteriorEstimator(NeuralInference, ABC):
             self._neural_net.train()
             for batch in train_loader:
                 optimizer.zero_grad()
+                # Get batches on current device.
                 theta_batch, x_batch, masks_batch = (
                     batch[0].to(self._device),
                     batch[1].to(self._device),
@@ -359,6 +362,11 @@ class PosteriorEstimator(NeuralInference, ABC):
 
         if density_estimator is None:
             density_estimator = self._neural_net
+            # If internal net is used device is defined.
+            device = self._device
+        else:
+            # Otherwise, infer it from the device of the net parameters.
+            device = next(density_estimator.parameters()).device
 
         self._posterior = DirectPosterior(
             method_family="snpe",
@@ -369,6 +377,7 @@ class PosteriorEstimator(NeuralInference, ABC):
             sample_with_mcmc=sample_with_mcmc,
             mcmc_method=mcmc_method,
             mcmc_parameters=mcmc_parameters,
+            device=device,
         )
 
         self._posterior._num_trained_rounds = self._round + 1
